..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Distributions
=============

.. currentmodule:: bayespy.inference.vmp.nodes

.. autosummary::
   :toctree: generated/

   stochastic.Distribution
   expfamily.ExponentialFamilyDistribution
   gaussian.GaussianDistribution
   gaussian.GaussianARDDistribution
   gaussian.GaussianGammaDistribution
   gaussian.GaussianWishartDistribution
   gaussian_markov_chain.GaussianMarkovChainDistribution
   gaussian_markov_chain.SwitchingGaussianMarkovChainDistribution
   gaussian_markov_chain.VaryingGaussianMarkovChainDistribution
   gamma.GammaDistribution
   wishart.WishartDistribution
   beta.BetaDistribution
   dirichlet.DirichletDistribution
   bernoulli.BernoulliDistribution
   binomial.BinomialDistribution
   categorical.CategoricalDistribution
   categorical_markov_chain.CategoricalMarkovChainDistribution
   multinomial.MultinomialDistribution
   poisson.PoissonDistribution
